@@ -16,6 +16,8 @@ try:
 except ImportError:
     import urllib as parse  # for Python 2
 
+from datetime import datetime as DT
+from dateutil.tz import tzutc
 from dateutil import parser
 import ks3.utils
 from ks3 import handler
@@ -296,7 +298,10 @@ class Bucket(object):
             fd.seek(0)
         for k in keys:
             if isinstance(k, Key):
-                datetime = int(round(parser.parse(k.last_modified).timestamp()))
+                if hasattr(DT, "timestamp"):
+                    datetime = int(round(parser.parse(k.last_modified).timestamp()))
+                else:
+                    datetime = int(round((parser.parse(k.last_modified) - DT(1970, 1, 1, tzinfo=tzutc())).total_seconds()))
                 if startTime is None and endTime is not None:
                     if (datetime >= endTime):
                         keyLists.append(k.name)
